==> haskell-equivalence-0.3.5-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 equivalence
version:              0.3.5
visibility:           public
id:                   equivalence-0.3.5-4vJeL1Bd0NK8oXKnXtT3le
key:                  equivalence-0.3.5-4vJeL1Bd0NK8oXKnXtT3le
license:              BSD-3-Clause
maintainer:           paba@itu.dk
author:               Patrick Bahr
stability:            provisional
homepage:             https://github.com/pa-ba/equivalence
synopsis:
    Maintaining an equivalence relation implemented as union-find using STT.

description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).

category:             Algorithms, Data
abi:                  47c146d0d99a78509f0730ed692772a3
exposed:              True
exposed-modules:      Data.Equivalence.Monad Data.Equivalence.STT
import-dirs:          /usr/lib/ghc-8.10.2/site-local/equivalence-0.3.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/equivalence-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/equivalence-0.3.5
hs-libraries:         HSequivalence-0.3.5-4vJeL1Bd0NK8oXKnXtT3le
depends:
    STMonadTrans-0.4.4-H8oMhtcUwffGkFpEsz8SY9 base-4.14.1.0
    containers-0.6.2.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:   /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html:         /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.3.5-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 equivalence
version:              0.3.5
visibility:           public
id:                   equivalence-0.3.5-97cytCSfKRo3hbqW0yxcGK
key:                  equivalence-0.3.5-97cytCSfKRo3hbqW0yxcGK
license:              BSD-3-Clause
maintainer:           paba@itu.dk
author:               Patrick Bahr
stability:            provisional
homepage:             https://github.com/pa-ba/equivalence
synopsis:
    Maintaining an equivalence relation implemented as union-find using STT.

description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).

category:             Algorithms, Data
abi:                  5db6a874d440048086c4c9f0730b5c7a
exposed:              True
exposed-modules:      Data.Equivalence.Monad Data.Equivalence.STT
import-dirs:          /usr/lib/ghc-8.10.2/site-local/equivalence-0.3.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/equivalence-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/equivalence-0.3.5
hs-libraries:         HSequivalence-0.3.5-97cytCSfKRo3hbqW0yxcGK
depends:
    STMonadTrans-0.4.4-70ryX5jqJv02KFHdzBv6IL base-4.14.1.0
    containers-0.6.2.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:   /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html:         /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
